@@ -494,8 +494,7 @@ class ServiceManagerClient(metaclass=ServiceManagerClientMeta):
 
         Args:
             request (Union[google.cloud.servicemanagement_v1.types.ListServicesRequest, dict]):
-                The request object. Request message for `ListServices`
-                method.
+                The request object. Request message for ``ListServices`` method.
             producer_project_id (str):
                 Include services produced by the
                 specified project.
@@ -615,8 +614,7 @@ class ServiceManagerClient(metaclass=ServiceManagerClientMeta):
 
         Args:
             request (Union[google.cloud.servicemanagement_v1.types.GetServiceRequest, dict]):
-                The request object. Request message for `GetService`
-                method.
+                The request object. Request message for ``GetService`` method.
             service_name (str):
                 Required. The name of the service. See the
                 ``ServiceManager`` overview for naming requirements. For
@@ -1835,8 +1833,8 @@ class ServiceManagerClient(metaclass=ServiceManagerClientMeta):
 
         Args:
             request (Union[google.cloud.servicemanagement_v1.types.GetServiceRolloutRequest, dict]):
-                The request object. Request message for
-                GetServiceRollout method.
+                The request object. Request message for GetServiceRollout
+                method.
             service_name (str):
                 Required. The name of the service. See the
                 `overview <https://cloud.google.com/service-infrastructure/docs/overview>`__
