@@ -17,7 +17,7 @@
 import dataclasses
 import json  # type: ignore
 import re
-from typing import Callable, Dict, List, Optional, Sequence, Tuple, Union
+from typing import Any, Callable, Dict, List, Optional, Sequence, Tuple, Union
 import warnings
 
 from google.api_core import (
@@ -618,7 +618,7 @@ class ServiceManagerRestTransport(ServiceManagerTransport):
         def __hash__(self):
             return hash("CreateService")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -642,7 +642,6 @@ class ServiceManagerRestTransport(ServiceManagerTransport):
                 request (~.servicemanager.CreateServiceRequest):
                     The request object. Request message for CreateService
                 method.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -716,7 +715,7 @@ class ServiceManagerRestTransport(ServiceManagerTransport):
         def __hash__(self):
             return hash("CreateServiceConfig")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -740,7 +739,6 @@ class ServiceManagerRestTransport(ServiceManagerTransport):
                 request (~.servicemanager.CreateServiceConfigRequest):
                     The request object. Request message for
                 CreateServiceConfig method.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -852,7 +850,7 @@ class ServiceManagerRestTransport(ServiceManagerTransport):
         def __hash__(self):
             return hash("CreateServiceRollout")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -876,7 +874,6 @@ class ServiceManagerRestTransport(ServiceManagerTransport):
                 request (~.servicemanager.CreateServiceRolloutRequest):
                     The request object. Request message for
                 'CreateServiceRollout'
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -952,7 +949,7 @@ class ServiceManagerRestTransport(ServiceManagerTransport):
         def __hash__(self):
             return hash("DeleteService")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -976,7 +973,6 @@ class ServiceManagerRestTransport(ServiceManagerTransport):
                 request (~.servicemanager.DeleteServiceRequest):
                     The request object. Request message for DeleteService
                 method.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -1041,7 +1037,7 @@ class ServiceManagerRestTransport(ServiceManagerTransport):
         def __hash__(self):
             return hash("GenerateConfigReport")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -1065,7 +1061,6 @@ class ServiceManagerRestTransport(ServiceManagerTransport):
                 request (~.servicemanager.GenerateConfigReportRequest):
                     The request object. Request message for
                 GenerateConfigReport method.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -1142,7 +1137,7 @@ class ServiceManagerRestTransport(ServiceManagerTransport):
         def __hash__(self):
             return hash("GetService")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -1231,7 +1226,7 @@ class ServiceManagerRestTransport(ServiceManagerTransport):
         def __hash__(self):
             return hash("GetServiceConfig")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -1255,7 +1250,6 @@ class ServiceManagerRestTransport(ServiceManagerTransport):
                 request (~.servicemanager.GetServiceConfigRequest):
                     The request object. Request message for GetServiceConfig
                 method.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -1362,7 +1356,7 @@ class ServiceManagerRestTransport(ServiceManagerTransport):
         def __hash__(self):
             return hash("GetServiceRollout")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -1386,7 +1380,6 @@ class ServiceManagerRestTransport(ServiceManagerTransport):
                 request (~.servicemanager.GetServiceRolloutRequest):
                     The request object. Request message for GetServiceRollout
                 method.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -1458,7 +1451,7 @@ class ServiceManagerRestTransport(ServiceManagerTransport):
         def __hash__(self):
             return hash("ListServiceConfigs")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -1482,7 +1475,6 @@ class ServiceManagerRestTransport(ServiceManagerTransport):
                 request (~.servicemanager.ListServiceConfigsRequest):
                     The request object. Request message for
                 ListServiceConfigs method.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -1550,7 +1542,7 @@ class ServiceManagerRestTransport(ServiceManagerTransport):
         def __hash__(self):
             return hash("ListServiceRollouts")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {
             "filter": "",
         }
 
@@ -1576,7 +1568,6 @@ class ServiceManagerRestTransport(ServiceManagerTransport):
                 request (~.servicemanager.ListServiceRolloutsRequest):
                     The request object. Request message for
                 'ListServiceRollouts'
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -1719,7 +1710,7 @@ class ServiceManagerRestTransport(ServiceManagerTransport):
         def __hash__(self):
             return hash("SubmitConfigSource")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -1743,7 +1734,6 @@ class ServiceManagerRestTransport(ServiceManagerTransport):
                 request (~.servicemanager.SubmitConfigSourceRequest):
                     The request object. Request message for
                 SubmitConfigSource method.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -1819,7 +1809,7 @@ class ServiceManagerRestTransport(ServiceManagerTransport):
         def __hash__(self):
             return hash("UndeleteService")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -1843,7 +1833,6 @@ class ServiceManagerRestTransport(ServiceManagerTransport):
                 request (~.servicemanager.UndeleteServiceRequest):
                     The request object. Request message for UndeleteService
                 method.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
